pub trait PrimitiveAtom:
Sized
+ Copy
+ Sealed {
type Impl: Send + Sync + Unpin;
}Expand description
Primitive types that can directly be used in an atomic way.
This trait is implemented exactly for every type that has a corresponding
atomic type in std::sync::atomic. You cannot implement this trait for
your own types; see Atom instead. This trait’s items are not part of
the public API – see the module docs.
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<T> PrimitiveAtom for *mut T
Available on target_has_atomic=ptr only.
impl<T> PrimitiveAtom for *mut T
Available on
target_has_atomic=ptr only.